/*
 * Author:  Konrad Rzeszutek <conradus@mindless.com>
 * Date:    Oct 19th 1999
 * File:    Editor3D/FaceObject.java
 *
 * Notes:
 *
 *   A face is set of various 3D/2D points.
 *   This object holds the point(s) assoicated with this face. It also
 *   has some basic method to matrix multiply all the points against a 
 *   matrix.
 *   
 */
 package Editor3D;
 
import java.util.*;

public class FaceObject {

    /*
     * Initalizes the FaceObject.
     *
     * require:
     *   size >=- 1
     *
     */    
    public FaceObject(int size) {
        
	vec = new Vector(size,0);
	capacity = size;
    }
    
    /*
     * Adds a point to the face.
     *
     * require:
     *   elmnt !- null && (this.size() < this.capacity)
     *
     */
    public void add(VectorObject elmnt) {
    
	vec.addElement( (Object) elmnt);
    }
    
    /*
     * Receives the specified VectorObject.
     *
     * require:
     *  0 <= index <= capacity.
     *
     */
    public VectorObject get(int index) {
    
	return (VectorObject) vec.elementAt(index);
    }
    
    /*
     * Returns the amount of points currently deposited.
     *
     * return:
     *   >= 0
     *
     */
    public int size() {
    
	return vec.size();
    }
    
    /*
     * Multiply all points held by this face against m matrix.
     *
     * require:
     *  m.rows == m.columns == 4
     *
     */
    public void multiply(Matrix m) {
    
	// Dot product all points against m Matrix,
	       System.out.print("["+vec.size()+"]");
    	for (int i = 0; i < vec.size(); i++) {
	    ((VectorObject) (vec.elementAt(i))).multiply(m);
	    //System.out.println(vec.elementAt(i));
	    }

    }
    /*
     * Multiply the WC of all the points held by the face against the m matrix.
     *
     * require:
     *  m.rows == m.columns == 4.
     *
     */
    public void  recalcWC(Matrix m) {
    
    	for (int i = 0; i < vec.size(); i++) 
	    ((VectorObject) (vec.elementAt(i))).recalcWC(m);

    }

    public void homogonize() {
        
    	for (int i = 0; i < vec.size(); i++) 
	    ((VectorObject) (vec.elementAt(i))).homogonize();

    }

   /*
    * Reset all the data to the original given ones.
    *
    */
    public void reset() {

       	for (int i = 0; i < vec.size(); i++)
	    ((VectorObject) (vec.elementAt(i))).reset();
   }
   /*
    * String representation off the face (including the points).
    *
    * return:
    *   String.
    *
    */
    public String toString() {
    
	String s = "Points in this face:\n";
	for (int i = 0; i < vec.size(); i++)
	    s+= vec.elementAt(i).toString();
	return s;
    }
    

    private Vector vec; //List of all points.
    int capacity;
}
